| Title: | Datasets for Use in Designing Surveys in Liberia |
|---|---|
| Description: | Designing surveys require relevant datasets to be used as basis for sample size calculations, sampling design, survey planning/logistics and survey implementation. These include datasets on population, lists of sampling clusters, map datasets for spatial sampling, and previous survey datasets that can be used for estimating indicator variance and design effects. This package contains relevant datasets for use in designing surveys in Liberia. |
| Authors: | Ernest Guevarra [aut, cre] (ORCID: <https://orcid.org/0000-0002-4887-4415>) |
| Maintainer: | Ernest Guevarra <[email protected]> |
| License: | CC0 |
| Version: | 0.0.0.9000 |
| Built: | 2026-06-04 09:24:17 UTC |
| Source: | https://github.com/spatialworks/liberia |
Administrative Level 2 (clans) map of Liberia
clansclans
A SpatialPolygonsDataFrame with 305 features:
IDObject identifier
LBLClan identifier
FIPTwo character country code for Liberia
MMT_IDThree character country code for Liberia
SHORT__FRMShort form name for Liberia
LONG_FRMLong form name for Liberia
ADM0Administrative level 0 of Liberia (Country name)
ADM1Administrative level 1 of Liberia (County name)
ADM2Administrative level 2 of Liberia (District name)
ADM3Administrative level 3 of Liberia (Clan name)
Map Maker Ltd. (2007). Clans, Liberia, 2007 Map Maker, Ltd. Available at: http://purl.stanford.edu/vm535pw6013.
Administrative Level 1 (counties) map of Liberia
countiescounties
A SpatialPolygonsDataFrame with 15 features:
OBJECTIDObject identifier
CNTRY_CODEThree-character ISO country code. For Liberia it is LBR.
WHO_CODEThree-character WHO country code. For Liberia it is LIB.
HrparentHR Parent
Shape_LengLength of shape
Shape_AreaArea of shape
admin1nameName of county
admin1PcodCounty postal code
admin0nameName of country
admin0PcodCountry postal code. LR for Liberia.
Pcod1_iso3County postal code using ISO3 code
https://data.humdata.org/dataset/liberia-admin-level-2-boundaries
Administrative Level 2 (districts) map of Liberia
districtsdistricts
A SpatialPolygonsDataFrame with 136 features:
OBJECTIDObject identifier
CNTRY_NAMECountry name
CNTRY_CODEThree-character ISO country code. For Liberia it is LBR.
WHO_CODEThree-character WHO country code. For Liberia it is LIB.
Shape_LengLength of shape
Shape_AreaArea of shape
admin1nameName of county
admin1PcodCounty postal code
admin2nameName of district
admin2PcodDistrict postal code
Pcod1_iso3County postal code using ISO3 code
Pcod2_iso3District postal code using ISO3 code
https://data.humdata.org/dataset/liberia-admin-level-2-boundaries
Dataset of enumeration areas with population size for Grand Bassa and Rural Montserrado
enumerationAreaenumerationArea
A data.frame with 8 columns and 751 rows
CountyName of county
DistrictName of district
ClanName of clan
EACODEEnumeration area code
MALENumber of male population
FEMALENumber of female population
HHNumber of households
TOTALTotal population
Liberia Institute of Statistics and Geo-Information Services
Enumeration area map of Grand Bassa county
grandBassaEAgrandBassaEA
A SpatialPolygonsDataFrame with 468 features:
CCNAMECounty name
DNAMEDistrict name
CLNAMEClan name
FEACODEFull EA code
SAREAArea map label
EFEACODEExtended full EA code
CCODECounty code
DCODEDistrict code
CLCODEClan code
EACODEEnumeration area code
TOTALTotal population
MALEMale population
FEMALEFemale population
HHTotal households
CCODE1Extended county code
DCODE1Extended district code
CLCODE1Extended clan code
EACODE1Extended enumeration area code
Liberia Institute of Statistics and Geo-Information Services
Enumeration area map of Greater Monrovia District
greaterMonroviaEAgreaterMonroviaEA
A SpatialPolygonsDataFrame with 1967 features:
CCNAMECounty name
DNAMEDistrict name
CLNAMEClan name
FEACODEFull EA code
SAREAArea map label
EFEACODEExtended full EA code
CCODECounty code
DCODEDistrict code
CLCODEClan code
EACODEEnumeration area code
TOTALTotal population
MALEMale population
FEMALEFemale population
HHTotal households
CCODE1Extended county code
DCODE1Extended district code
CLCODE1Extended clan code
EACODE1Extended enumeration area code
Liberia Institute of Statistics and Geo-Information Services
Datasets for Use in Designing Surveys in Liberia
Designing surveys require relevant datasets to be used as basis for sample size calculations, sampling design, survey planning/logistics and survey implementation. These include datasets on population, lists of sampling clusters, map datasets for spatial sampling, and previous survey datasets that can be used for estimating indicator variance and design effects. This package contains relevant datasets for use in designing surveys in Liberia.
Maintainer: Ernest Guevarra [email protected] (ORCID)
Useful links:
Report bugs at https://github.com/validmeasures/liberia/issues
Dataset of localities with population size for Grand Bassa and Rural Montserrado
localitylocality
A data.frame with 9 columns and 3412 rows
FIDLocality ID
CountyName of county
DistrictName of district
ClanName of clan
`Locality/ Town`Name of locality/town
MALENumber of male population
FEMALENumber of female population
TOTALTotal population
HHNumber of households
Liberia Institute of Statistics and Geo-Information Services
Dataset of enumeration areas with population size for Greater Monrovia District
monroviamonrovia
A data.frame with 8 columns and 751 rows
CountyName of county
DistrictName of district
Town/LocalityTown or locality name
MALENumber of male population
FEMALENumber of female population
TOTALTotal population
Liberia Institute of Statistics and Geo-Information Services
Map of settlement locations in Liberia
settlementssettlements
A SpatialPointsDataFrame with 14013 features:
OBJECTIDObject identifier
FNAMESettlement name
CLASSA numeric value specifying the settlement class. 1 = Capital of country; 2 = Capital of county; 3 = Capital of district; 0 = village
DESCRIPTIOA string value describing the settlement class based
on CLASS
COORD_XLongitude coordinate of settlement
COORD_YLatitude coordiante of settlement
admin1nameName of county
admin1PcodCounty postal code
admin2nameName of district
admin2PcodDistrict postal code
admin0nameName of country
admin0PcodCountry postal code. LR for Liberia.
rowcacode0Three-character ISO country code
Pcod1_iso3County postal code using ISO3 code
Pcod2_iso3District postal code using ISO3 code
https://data.humdata.org/dataset/liberia-settlements-0